HandMode enum

Detection mode controlling the two-stage pipeline behavior.

  • boxes: Fast detection returning only bounding boxes (Stage 1 only)
  • boxesAndLandmarks: Full pipeline returning boxes + landmarks (both stages)
Inheritance
Available extensions

Values

boxes → const HandMode

Fast detection mode returning only bounding boxes (Stage 1 only).

boxesAndLandmarks → const HandMode

Full pipeline mode returning bounding boxes and landmarks per hand.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HandMode>
A constant List of the values in this enum, in order of their declaration.