HandDetector constructor
HandDetector()
Creates a hand detector instance.
The detector is not ready for use until you call initialize.
Implementation
HandDetector();
Creates a hand detector instance.
The detector is not ready for use until you call initialize.
HandDetector();