isInitialized property
bool
get
isInitialized
Returns true if the detector has been initialized and is ready to use.
Implementation
bool get isInitialized => isReady;
Returns true if the detector has been initialized and is ready to use.
bool get isInitialized => isReady;