detectHandsFromMatBytes method

Future<List<Hand>> detectHandsFromMatBytes(
  1. Uint8List bytes, {
  2. required int width,
  3. required int height,
  4. int matType = 16,
})

Detects hands from raw pixel bytes in the background isolate.

Parameters:

  • bytes: Raw pixel data (typically BGR format, 3 bytes per pixel)
  • width: Image width in pixels
  • height: Image height in pixels
  • matType: OpenCV MatType value (default: CV_8UC3 = 16 for BGR)

Returns a list of Hand objects, one per detected hand.

Implementation

Future<List<Hand>> detectHandsFromMatBytes(
  Uint8List bytes, {
  required int width,
  required int height,
  int matType = 16,
}) =>
    _detector.detectFromMatBytes(bytes,
        width: width, height: height, matType: matType);