detectHands method
Detects hands in the given encoded image in the background isolate.
Parameters:
Returns a list of Hand objects, one per detected hand.
Implementation
Future<List<Hand>> detectHands(List<int> imageBytes) => _detector.detect(
imageBytes is Uint8List ? imageBytes : Uint8List.fromList(imageBytes));